@@ -73,6 +73,8 @@ import de.willuhn.jameica.hbci.rmi.Konto;
 import de.willuhn.jameica.hbci.rmi.Umsatz;
 import de.willuhn.jameica.hbci.rmi.UmsatzTyp;
 import de.willuhn.jameica.hbci.server.Range;
+import de.willuhn.jameica.hbci.server.Range.Category;
+import de.willuhn.jameica.hbci.server.UmsatzTypUtil;
 import de.willuhn.jameica.hbci.server.UmsatzUtil;
 import de.willuhn.jameica.messaging.StatusBarMessage;
 import de.willuhn.jameica.system.Application;
@@ -218,7 +220,23 @@ public class KontoauszugList extends UmsatzList
         handlePrint();
       }
     },null,false,"document-save.png");
-    buttons.addButton(i18n.tr("Umstze abrufen..."), new KontoFetchUmsaetze(),null,false,"mail-send-receive.png");
+    buttons.addButton(i18n.tr("Umstze abrufen..."), new Action() {
+      
+      @Override
+      public void handleAction(Object context) throws ApplicationException
+      {
+        Object ctx = null;
+        try
+        {
+          ctx = getKontoAuswahl().getValue();
+        }
+        catch (RemoteException re)
+        {
+          Logger.error("unable to get current konto",re);
+        }
+        new KontoFetchUmsaetze().handleAction(ctx);
+      }
+    },null,false,"mail-send-receive.png");
     buttons.addButton(i18n.tr("Filter zurcksetzen"), new Action()
     {
       public void handleAction(Object context) throws ApplicationException
@@ -325,7 +343,6 @@ public class KontoauszugList extends UmsatzList
     this.start = new DateFromInput(null,"umsatzlist.filter.from");
     this.start.setName(i18n.tr("Von"));
     this.start.setComment(null);
-    this.start.addListener(this.listener);
     return this.start;
   }
   
@@ -341,7 +358,6 @@ public class KontoauszugList extends UmsatzList
     this.end = new DateToInput(null,"umsatzlist.filter.to");
     this.end.setName(i18n.tr("bis"));
     this.end.setComment(null);
-    this.end.addListener(this.listener);
     return this.end;
   }
   
@@ -354,7 +370,7 @@ public class KontoauszugList extends UmsatzList
     if (this.range != null)
       return this.range;
     
-    this.range = new RangeInput(this.getStart(),this.getEnd(),"umsatzlist.filter.range");
+    this.range = new RangeInput(this.getStart(),this.getEnd(),Category.AUSWERTUNG,"umsatzlist.filter.range");
     this.range.addListener(new Listener()
     {
       public void handleEvent(Event event)
@@ -378,13 +394,13 @@ public class KontoauszugList extends UmsatzList
       return this.kategorie;
     
     UmsatzTyp preset = (UmsatzTyp) cache.get("kontoauszug.list.kategorie");
-    if (preset == null || preset.getID() == null)
-      preset = null; // wurde zwischenzeitlich geloescht
+    if (preset == null || (preset.getID() == null && preset != UmsatzTypUtil.UNASSIGNED)) // // ID ist NULL, wenn sie zwischenzeitlich geloescht wurde
+      preset = null; 
     this.kategorie = new UmsatzTypInput(preset,UmsatzTyp.TYP_EGAL, true);
     this.kategorie.setPleaseChoose(i18n.tr("<Alle Kategorien>"));
     this.kategorie.setComment("");
     this.kategorie.addListener(this.listener);
-    
+
     // Wenn in der Kategorie-Auswahl "<Alle Kategorien>" ausgewaehlt wurde, deaktivieren wir uns
     this.kategorie.addListener(new Listener()
     {
@@ -650,7 +666,7 @@ public class KontoauszugList extends UmsatzList
     if (typ != null) this.filterCount++;
 
     if (this.filterCount > 0)
-    Application.getMessagingFactory().sendMessage(new StatusBarMessage(i18n.tr("Anzahl der Suchkriterien: {0}",Integer.toString(this.filterCount)),StatusBarMessage.TYPE_INFO));
+      Application.getMessagingFactory().sendMessage(new StatusBarMessage(i18n.tr("Anzahl der Suchkriterien: {0}",Integer.toString(this.filterCount)),StatusBarMessage.TYPE_INFO));
     
     if (search != null)
     {
@@ -697,17 +713,14 @@ public class KontoauszugList extends UmsatzList
    */
   private boolean matches(UmsatzTyp typ, Umsatz u, boolean children) throws RemoteException
   {
-    // Keine rekursive Suche
-    if (!children)
-      return typ.matches(u);
+    UmsatzTyp t = u.getUmsatzTyp();
+    
+    if (t == null && typ != null && typ == UmsatzTypUtil.UNASSIGNED)
+      return true;
 
     // wir suchen von unten nach oben, indem wir die Umsatzkategorien
     // des Umsatzes nach oben iterieren. Wenn wir dabei auf die gesuchte
     // Kategorie stossen, passts.
-    UmsatzTyp t = u.getUmsatzTyp();
-    
-    if (t == null)
-      return false; // nichts zum Suchen da
     
     for (int i=0;i<100;++i) // maximal 100 Iterationen - fuer den (eigentlich unmoeglichen Fall), dass eine Rekursion existiert
     {
@@ -716,6 +729,10 @@ public class KontoauszugList extends UmsatzList
       
       if (t.equals(typ))
         return true; // passt!
+
+      // Keine rekursive Suche
+      if (!children)
+        break;
       
       t = (UmsatzTyp) t.getParent(); // weiter nach oben gehen
     }
@@ -754,7 +771,7 @@ public class KontoauszugList extends UmsatzList
       Exporter.SESSION.put("pdf.start",getStart().getValue());
       Exporter.SESSION.put("pdf.end",getEnd().getValue());
 
-      Umsatz[] u = (Umsatz[]) list.toArray(new Umsatz[list.size()]);
+      Umsatz[] u = (Umsatz[]) list.toArray(new Umsatz[0]);
       new UmsatzExport().handleAction(u);
     }
     catch (ApplicationException ae)
@@ -845,6 +862,9 @@ public class KontoauszugList extends UmsatzList
       
       // Zum Schluss Sortierung aktualisieren
       sort();
+      
+      // Und die markierten Datensaetze wiederherstellen
+      restoreState();
     }
     catch (Exception e)
     {
@@ -918,7 +938,6 @@ public class KontoauszugList extends UmsatzList
 
   /**
    * Hilfsklasse fuer das Suchfeld.
-   * @author willuhn
    */
   private class SearchInput extends ButtonInput
   {
@@ -951,7 +970,7 @@ public class KontoauszugList extends UmsatzList
                 
                 // Mal schauen, obs den Typ schon gibt
                 DBIterator existing = de.willuhn.jameica.hbci.Settings.getDBService().createList(UmsatzTyp.class);
-                existing.addFilter("pattern = ?", new Object[]{text});
+                existing.addFilter("pattern = ?", text);
                 UmsatzTyp typ = null; 
                 if (existing.size() > 0)
                 {
@@ -1046,16 +1065,20 @@ public class KontoauszugList extends UmsatzList
       String s = (String) cache.get("kontoauszug.list.search");
       this.setValue(s);
       this.hasChanged(); // Einmal initial triggern, damit bereits die erste Text-Eingabe als Aenderung erkannt wird
-      this.text.addKeyListener(new KeyAdapter() {
-        /**
-         * @see org.eclipse.swt.events.KeyAdapter#keyReleased(org.eclipse.swt.events.KeyEvent)
-         */
-        @Override
-        public void keyReleased(KeyEvent e)
-        {
-          listener.handleEvent(null);
-        }
-      });
+      
+      if (syssettings.getBoolean("usage.instantsearch",false))
+      {
+        this.text.addKeyListener(new KeyAdapter() {
+          /**
+           * @see org.eclipse.swt.events.KeyAdapter#keyReleased(org.eclipse.swt.events.KeyEvent)
+           */
+          @Override
+          public void keyReleased(KeyEvent e)
+          {
+            listener.handleEvent(null);
+          }
+        });
+      }
       return this.text;
     }
 
